package com.javacodegeeks;

import static io.restassured.RestAssured.when;
import static org.hamcrest.CoreMatchers.equalTo;

import org.arquillian.cube.docker.impl.client.containerobject.dsl.AwaitBuilder;
import org.arquillian.cube.docker.junit.rule.ContainerDslRule;
import org.arquillian.cube.docker.junit.rule.NetworkDslRule;
import org.junit.BeforeClass;
import org.junit.ClassRule;
import org.junit.Test;

import io.restassured.RestAssured;

public class SpringBootAppIntegrationTest {
    @ClassRule
    public static NetworkDslRule network = new NetworkDslRule("my-app-network");
    
    @ClassRule
    public static ContainerDslRule mysql = new ContainerDslRule("mysql:8.0.2", "mysql")
        .withEnvironment("MYSQL_ROOT_PASSWORD", "p$ssw0rd")
        .withEnvironment("MYSQL_DATABASE", "my_app_db")
        .withEnvironment("MYSQL_ROOT_HOST", "%")
        .withExposedPorts(3306)
        .withNetworkMode("my-app-network")
        .withAwaitStrategy(AwaitBuilder.logAwait("/usr/sbin/mysqld: ready for connections"));
    
    @ClassRule
    public static ContainerDslRule javaApp = new ContainerDslRule("jcg/spring-boot-webapp:latest", "spring-boot-webapp*")
        .withEnvironment("DB_HOST", "mysql")
        .withPortBinding(19900)
        .withNetworkMode("my-app-network")
        .withLink("mysql", "mysql")
        .withAwaitStrategy(AwaitBuilder.logAwait("Started AppStarter"));

    @BeforeClass
    public static void setUp() {
        RestAssured.baseURI = "http://" + javaApp.getIpAddress();
        RestAssured.port = javaApp.getBindPort(19900);
    }
    
    @Test
    public void getAllTasks() {
        when()
            .get("/tasks")
            .then()
            .statusCode(200)
            .body(equalTo("[]"));
    }
}
