package com.javacodegeeks;

import static io.restassured.RestAssured.when;
import static org.hamcrest.CoreMatchers.equalTo;

import org.joda.time.Duration;
import org.junit.BeforeClass;
import org.junit.ClassRule;
import org.junit.Test;

import com.palantir.docker.compose.DockerComposeRule;
import com.palantir.docker.compose.configuration.ShutdownStrategy;
import com.palantir.docker.compose.connection.DockerPort;
import com.palantir.docker.compose.connection.waiting.HealthChecks;

import io.restassured.RestAssured;

public class SpringBootAppIntegrationTest {
    @ClassRule
    public static DockerComposeRule docker = DockerComposeRule.builder()
        .file("src/test/resources/docker-compose.yml")
        .waitingForService("java-app", 
                HealthChecks.toRespond2xxOverHttp(19900, (port) -> port.inFormat("http://$HOST:$EXTERNAL_PORT/application/health")),
                Duration.standardSeconds(30)
            )
        .shutdownStrategy(ShutdownStrategy.GRACEFUL)
        .build();
    
    @BeforeClass
    public static void setUp() {
        final DockerPort port = docker.containers().container("java-app").port(19900);
        RestAssured.baseURI = port.inFormat("http://$HOST");
        RestAssured.port = port.getExternalPort();
    }
    
    @Test
    public void getAllTasks() {
        when()
            .get("/tasks")
            .then()
            .statusCode(200)
            .body(equalTo("[]"));
    }
}
