package com.javacodegeeks;

import static io.restassured.RestAssured.when;
import static org.awaitility.Awaitility.await;
import static org.hamcrest.CoreMatchers.equalTo;

import java.util.concurrent.TimeUnit;

import org.junit.AfterClass;
import org.junit.BeforeClass;
import org.junit.Test;

import com.xebialabs.overcast.host.CloudHost;
import com.xebialabs.overcast.host.CloudHostFactory;

import io.restassured.RestAssured;

public class SpringBootAppIntegrationTest {
    private static CloudHost mysql = CloudHostFactory.getCloudHost("mysql");
    private static CloudHost javaApp = CloudHostFactory.getCloudHost("spring-boot-webapp");
    
    @BeforeClass
    public static void setUp() {
        mysql.setup();
        javaApp.setup();
        
        RestAssured.baseURI = "http://" + javaApp.getHostName();
        RestAssured.port = javaApp.getPort(19900);
        
        await()
            .atMost(20, TimeUnit.SECONDS)
            .ignoreExceptions()
            .pollInterval(1, TimeUnit.SECONDS)
            .untilAsserted(() -> 
                when()
                    .get("/application/health")
                    .then()
                    .statusCode(200));
    }
    
    @AfterClass
    public static void tearDown() {
        javaApp.teardown();
        mysql.teardown();
    }
    
    @Test
    public void getAllTasks() {
        when()
            .get("/tasks")
            .then()
            .statusCode(200)
            .body(equalTo("[]"));
    }
}
