package com.javacodegeeks;

import static io.restassured.RestAssured.when;
import static org.hamcrest.CoreMatchers.equalTo;

import org.junit.BeforeClass;
import org.junit.ClassRule;
import org.junit.Test;
import org.testcontainers.containers.GenericContainer;
import org.testcontainers.containers.Network;
import org.testcontainers.containers.wait.HostPortWaitStrategy;

import io.restassured.RestAssured;

public class SpringBootAppIntegrationTest {
	@ClassRule
	public static Network network = Network.newNetwork();
	
    @ClassRule
    public static GenericContainer<?> mysql = new GenericContainer<>("mysql:8.0.2")
    	.withEnv("MYSQL_ROOT_PASSWORD", "p$ssw0rd")
        .withEnv("MYSQL_DATABASE", "my_app_db")
    	.withEnv("MYSQL_ROOT_HOST", "%")
        .withExposedPorts(3306)
        .withNetwork(network)
        .withNetworkAliases("mysql")
        .waitingFor(new HostPortWaitStrategy());
    
    @ClassRule
    public static GenericContainer<?> javaApp = new GenericContainer<>("jcg/spring-boot-webapp:latest")
        .withEnv("DB_HOST", "mysql")
        .withExposedPorts(19900)
        .withStartupAttempts(3)
        .withNetwork(network)
        .waitingFor(new HostPortWaitStrategy());
    
    @BeforeClass
    public static void setUp() {
        RestAssured.baseURI = "http://" + javaApp.getContainerIpAddress();
        RestAssured.port = javaApp.getMappedPort(19900);
    }
    
    @Test
    public void getAllTasks() {
        when()
            .get("/tasks")
            .then()
            .statusCode(200)
            .body(equalTo("[]"));
    }
}
